@@ -9,8 +9,10 @@ from QiDataProcessing.BarProvider import BarProvider
 from QiDataProcessing.BaseBarHelper import BaseBarHelper
 from QiDataProcessing.Core.Bar import Bar
 from QiDataProcessing.Core.EnumBarType import EnumBarType
+from QiDataProcessing.Core.EnumMarket import EnumMarket
 from QiDataProcessing.Core.EnumRestoration import EnumRestoration
 from QiDataProcessing.Core.TradingDayHelper import TradingDayHelper
+from QiDataProcessing.Instrument.InstrumentManager import InstrumentManager
 from QiDataProcessing.QiStream.DayBarStream import DayBarStream
 from QiDataProcessing.QiStream.MinBarStream import MinBarStream
 from QiDataProcessing.QiStream.TickStream import TickStream
@@ -18,7 +20,11 @@ from QiDataProcessing.TradingFrame.YfTimeHelper import YfTimeHelper
 
 
 class QiDataController:
-    def __init__(self, qi_data_directory, instrument_manager):
+    def __init__(self, qi_data_directory):
+        config_dir = os.path.split(os.path.realpath(__file__))[0] + "\\Config"
+        instrument_manager = InstrumentManager()
+        instrument_manager.load(config_dir, EnumMarket.期货)
+
         self.__trading_day = qi_data_directory.trading_day
         self.__instrument_manager = instrument_manager
 
