@@ -14,7 +14,6 @@ trading_day = datetime.datetime(2019, 10, 13)
 tick_path = "\\\\192.168.1.200\\MqData\\futuretick\\Future"
 min_path = "\\\\192.168.1.200\\MqData\\futuremin"
 day_path = "\\\\192.168.1.200\\MqData\\futureday"
-config_dir = "D:\WorkSpace\CarlSnow\Python\QiDataProcessing\QiDataProcessing\Config"
 
 qi_data_directory = QiDataDirectory()
 qi_data_directory.trading_day = trading_day
@@ -23,10 +22,7 @@ qi_data_directory.future_tick_cache = tick_path
 qi_data_directory.future_min = min_path
 qi_data_directory.future_day = day_path
 
-instrument_manager = InstrumentManager()
-instrument_manager.load(config_dir, EnumMarket.期货)
-
-qi_data_controller = QiDataController(qi_data_directory, instrument_manager)
+qi_data_controller = QiDataController(qi_data_directory)
 
 interval = 5
 bar_type = EnumBarType.day
